#
# spec file for package hfst
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           hfst
Version:        3.16.2
Release:        2.4
Summary:        Helsinki Finite-State Transducer Technology
License:        Apache-2.0 AND GPL-2.0-only AND GPL-2.0-or-later AND GPL-3.0-only AND GPL-3.0-or-later AND GPL-3.0-only
Group:          Development/Tools/Other
URL:            https://hfst.github.io/

Source:         https://github.com/hfst/hfst/archive/refs/tags/v%version.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex
BuildRequires:  foma-devel >= 0.9.18+git20210604
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  pkg-config
BuildRequires:  python3-base
BuildRequires:  readline-devel
BuildRequires:  openfst-devel
BuildRequires:  pkgconfig(icu-uc) >= 50
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(zlib)
Requires:       grep
Requires:       sed

%description
The Helsinki Finite-State Transducer software is intended for the
implementation of morphological analyzers and other tools which are
based on weighted and unweighted finite-state transducer technology.

%package -n libhfst55
Summary:        Helsinki Finite-State Transducer C++ API Library
License:        GPL-3.0-only
Group:          System/Libraries

%description -n libhfst55
The Helsinki Finite-State Transducer software is intended for the
implementation of morphological analyzers and other tools which are
based on weighted and unweighted finite-state transducer technology.

%ifarch %ix86
On 32-bit x86, this package requires the presence of SSE2.
%endif

%package -n libhfst_c0
Summary:        Helsinki Finite-State Transducer C API Library
License:        GPL-3.0-only
Group:          System/Libraries

%description -n libhfst_c0
The Helsinki Finite-State Transducer software is intended for the
implementation of morphological analyzers and other tools which are
based on weighted and unweighted finite-state transducer technology.

%package devel
Summary:        Development files for the Helsinki Finite-State Transducer
License:        GPL-3.0-only
Group:          Development/Libraries/C and C++
Requires:       libhfst55 = %version
Requires:       libhfst_c0 = %version

%description devel
The Helsinki Finite-State Transducer software is intended for the
implementation of morphological analyzers and other tools which are
based on weighted and unweighted finite-state transducer technology.

This subpackage contains the files necessary to build programs that
want to make use of the HFST library.

%prep
%autosetup -p1

%build
autoreconf -fiv
export CXXFLAGS="%optflags -std=c++17"
%configure --disable-static --with-readline \
	--enable-all-tools --includedir="%_includedir/%name" \
	--with-foma-upstream
%make_build

%install
%make_install
rm -fv "%buildroot/%_libdir"/*.la
# headers not installed
rm -fv "%buildroot/%_libdir/"{libfoma,libfst,libsfst}.so
%fdupes %buildroot/%_prefix

%ifarch %ix86 x86_64
%check
# https://github.com/hfst/hfst/issues/584 / other distros also do not run check
%make_build check -j1
%endif

%ldconfig_scriptlets -n libhfst55
%ldconfig_scriptlets -n libhfst_c0

%files
%_bindir/hfst*
%_mandir/man1/*.1*
%doc NEWS README
%license COPYING

%files -n libhfst55
%_libdir/libhfst.so.55*

%files -n libhfst_c0
%_libdir/libhfst_c.so.0*

%files devel
%_includedir/*
%_libdir/libhfst.so
%_libdir/libhfst_c.so
%_libdir/pkgconfig/*.pc
%_datadir/aclocal/

%changelog
* Tue Feb 25 2025 Jan Engelhardt <jengelh@inai.de>
- Deactivate tests on non-x86
* Sat Jan 18 2025 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.16.2
  * Removal of n-best paths search for log weight automata
  * Added an experimental C interface library
- Delete hfst-sse.diff which made i586 tests fail.
* Wed Nov 20 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.16.1
  * hfst-tokenize escapes both \r and \n now
  * regexp parsing more robust with comments and linebreaks
  * new tool "hfst-check-alpha" for checking and comparing
    alphabets in automata and their metadata
  * new tool "hfst-dump-alphabets" for reviewing alphabets easier
    than hfst-summarize grepping
  * new tool "hfst-kill-paths" for efficient path removal
- Delete 0001-build-fix-build-failure-with-ICU-75.patch,
  hfst-nodate.diff (merged)
* Tue Jun  4 2024 Jan Engelhardt <jengelh@inai.de>
- Add 0001-build-fix-build-failure-with-ICU-75.patch
* Thu Feb 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.16
  * hfst-pmatch archives now no longer include or parse redundant alphabets,
    which in some cases can be a meaningful size and speed saving.
  * C++14 is the minimal requirement.
  * Drop legacy wrappers for foma and lexc.
- Add hfst-sse.diff to get rid of forced SSE
* Thu May 27 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.15.5
  * pmatch: modified tracking of entry points to allow for RTNs
    in captures
  * pmatch: fixed off-by-one bug in checking captures
- Remove hfst-split-libs.diff, hfst-wrong-flags.diff,
  system-foma.diff (obsolete)
* Sat Feb 13 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.15.4
  * No user visible changes
* Thu Dec 19 2019 Jan Engelhardt <jengelh@inai.de>
- Update to release 3.15.2
  * Fix off-by-one bug in checking captures in pmatch.
  * hfst-pmatch2fst now implements eg @include"filename.txt" as a
    preprocessing stage.
  * hfst-pmatch2fst now implements Explode() and Implode() in
    full generality.
  * hfst-pmatch now allows printing weights (in location mode,
    with --locate).
  * Add tool hfst-eliminate-flags.
  * Allow both escaped and unescaped zeros in multicharacters in
    all lexc lexicon entries.
* Thu Aug 22 2019 Jan Engelhardt <jengelh@inai.de>
- Update to new upstream release 3.15.0
  * Numerous improvements to pmatching and tokenization.
  * Add tool hfst-eliminate-flags.
  * Allow both escaped and unescaped zeros in multicharacters in
    all lexc lexicon entries.
- Drop gcc7.diff, hfst-scripts-install.diff
* Tue Sep  5 2017 jengelh@inai.de
- Add gcc7.diff
* Thu Apr 27 2017 jengelh@inai.de
- Update to new upstream release 3.12.2
  * Implement hfst-twolc as a single program instead of a script. Get
  rid of hfst-twolc-system and hfst-twolc-loc tools.
- Remove hfst-badcode.diff (applied upstream)
* Thu Sep 11 2014 jengelh@inai.de
- Initial package for build.opensuse.org (version 3.7.2)
